import{N as k}from"./Navbar.df02de65.js";import{B as N}from"./BaseLayout.0056f742.js";import{C as I}from"./ContentLayout.231b4f8d.js";import{C as _}from"./CrudView.178ed8b6.js";import{a as O}from"./asyncComputed.15a1493f.js";import{F as x}from"./PhArrowSquareOut.vue.dcd6453d.js";import{G as R}from"./PhPencil.vue.8eeff64f.js";import{d as M,e5 as h,r as B,c as D,a5 as F,f as o,b as i,u as s,aR as V,o as f,a as $,cz as j,bJ as A,cy as E,h as G,M as L}from"./jwt-decode.esm.95147216.js";import"./router.09c25b35.js";import{a as m}from"./organization.21f2f03d.js";import"./tables.7fcaf771.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.ce90d792.js";import"./constants.5f7db9f7.js";import"./PhChats.vue.89b3bbbd.js";import"./PhSignOut.vue.88518a69.js";import"./index.b1615145.js";import"./index.c7a02ea6.js";import"./omniChatStore.5c421f6e.js";import"./record.44df96f2.js";import"./uuid.36c0f5f6.js";import"./PhCopySimple.vue.0dac09a8.js";import"./PhBookBookmark.vue.2d2fee75.js";import"./PhSparkle.vue.fc1ab30d.js";import"./index.ca714ac8.js";import"./Breadcrumb.fba01eee.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bfb97102.js";import"./url.8c481a5a.js";import"./PhDotsThreeVertical.vue.3f13d85f.js";import"./index.574c12ce.js";import"./string.c6b418fe.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},l=new Error().stack;l&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[l]="42b3697c-8afe-41b6-af25-c28a4151b225",r._sentryDebugIdIdentifier="sentry-dbid-42b3697c-8afe-41b6-af25-c28a4151b225")}catch{}})();const bt=M({__name:"Organizations",setup(r){const l=[{label:"My organizations",path:"/organizations"}],u=[{key:"name",label:"Organization Name"}],g=h(),{loading:y,result:b,refetch:v}=O(()=>m.list()),p=({key:e})=>{g.push({name:"organization",params:{organizationId:e}})},n=B({state:"idle"});function z(e){n.value={state:"renaming",organizationId:e.id,newName:e.name}}async function c(e){if(n.value.state==="renaming"&&e){const{organizationId:t,newName:a}=n.value;await m.rename(t,a),v()}n.value={state:"idle"}}const w=async e=>{const t=await m.create(e.name);p({key:t.id})},C=D(()=>{var e,t;return{columns:[{title:"Organization Name",align:"left"},{title:"Path"},{title:"",align:"right"}],rows:(t=(e=b.value)==null?void 0:e.map(a=>{var d;return{key:a.id,cells:[{type:"link",text:a.name,to:`/organizations/${encodeURIComponent(a.id)}`},{type:"text",text:(d=a.id)!=null?d:null},{type:"actions",actions:[{icon:x,label:"Go to projects",onClick:p},{icon:R,label:"Rename",onClick:()=>z(a)}]}]}}))!=null?t:[]}});return(e,t)=>(f(),F(V,null,[o(N,null,{navbar:i(()=>[o(k,{breadcrumb:l})]),content:i(()=>[o(I,null,{default:i(()=>[o(_,{"entity-name":"organization",loading:s(y),title:"My organizations",description:"An organization is your company\u2019s account. Manage editors, projects and billing.","create-button-text":"Create Organization","empty-title":"No organizations here yet",table:C.value,fields:u,create:w},null,8,["loading","table"])]),_:1})]),_:1}),o(s(L),{open:n.value.state==="renaming",title:"Rename organization",onCancel:t[1]||(t[1]=a=>c(!1)),onOk:t[2]||(t[2]=a=>c(!0))},{default:i(()=>[n.value.state==="renaming"?(f(),$(s(E),{key:0,layout:"vertical"},{default:i(()=>[o(s(j),{label:"New name"},{default:i(()=>[o(s(A),{value:n.value.newName,"onUpdate:value":t[0]||(t[0]=a=>n.value.newName=a)},null,8,["value"])]),_:1})]),_:1})):G("",!0)]),_:1},8,["open"])],64))}});export{bt as default};
//# sourceMappingURL=Organizations.417f96eb.js.map
