import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.dffc3ca0.js";import{A as v}from"./constants.5f7db9f7.js";import{d as A,eb as x,e5 as I,c as w,a5 as T,f as c,b as a,u as e,a as f,h as p,o as i,g as s,ed as l,A as B,T as m,bR as C,e as E,d8 as N,eG as o,_ as D}from"./jwt-decode.esm.95147216.js";import{u as R}from"./workspaceStore.ef22b01d.js";import{C as S}from"./Card.6c9b2903.js";import"./Logo.4a9353b0.js";import"./userStore.58432b7f.js";import"./url.8c481a5a.js";import"./colorHelpers.359e9af7.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new L().stack;d&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[d]="feaa8081-5252-438e-a037-57373c2757e4",r._sentryDebugIdIdentifier="sentry-dbid-feaa8081-5252-438e-a037-57373c2757e4")}catch{}})();const V={class:"inner-content"},G={class:"card-content"},H=A({__name:"Error",setup(r){const d=x(),g=I(),u=R(),y=w(()=>{var t,_,h;return(h=(t=u.state.workspace)==null?void 0:t.name)!=null?h:(_=u.state.workspace)==null?void 0:_.brandName}),n=w(()=>{const{status:t}=d.params;switch(t){case"404":return{status:t,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:t,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),b=()=>{g.push({name:"playerHome"})};return(t,_)=>(i(),T("div",V,[c(e(B),null,{default:a(()=>[s(l(n.value.title),1)]),_:1}),c(e(m),{class:"message"},{default:a(()=>[s(l(n.value.message),1)]),_:1}),n.value.action?(i(),f(e(C),{key:0,type:"link",onClick:b},{default:a(()=>[s(l(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(i(),f(e(S),{key:1,bordered:!1,class:"card"},{default:a(()=>[E("div",G,[c(k,{style:{"margin-bottom":"10px"}}),c(e(m),null,{default:a(()=>[s("This page is part of "+l(y.value?`the ${y.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u).state.workspace?(i(),f(e(m),{key:0},{default:a(()=>[s("Automate your own processes by getting started "),c(e(N),{href:e(v).HOMEPAGE},{default:a(()=>[s("here")]),_:1},8,["href"]),s(".")]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}});const L=D(H,[["__scopeId","data-v-522ad0d4"]]);export{L as default};
//# sourceMappingURL=Error.cd9b6608.js.map
