import{P as f}from"./PlayerNavbar.45c8bc2d.js";import{d as g,e5 as h,eb as i,r as y,c as b,m as k,a5 as v,u as n,a as w,h as L,e as C,f as I,o as c,_ as N}from"./jwt-decode.esm.95147216.js";import{u as V}from"./workspaceStore.ef22b01d.js";import"./userStore.58432b7f.js";import"./index.82e2f482.js";import"./metadata.b063d26f.js";import"./PhUserList.vue.8ad60021.js";import"./PhWebhooksLogo.vue.c419935e.js";import"./LoadingOutlined.d228c4b5.js";import"./PhSignOut.vue.88518a69.js";import"./index.c7a02ea6.js";import"./url.8c481a5a.js";import"./colorHelpers.359e9af7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="795ced53-4a2b-4793-96d4-ab6783e35ee3",o._sentryDebugIdIdentifier="sentry-dbid-795ced53-4a2b-4793-96d4-ab6783e35ee3")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=i().path,a=y(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},_=b(()=>!!i().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return c(),v("div",x,[n(t).state.workspace?(c(),w(f,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const H=N(D,[["__scopeId","data-v-f095bece"]]);export{H as default};
//# sourceMappingURL=Main.0632fdbf.js.map
