import{y as n,z as r,B as o,C as c,P as f,D as d,E as p,F as m,G as a,H as u,I as b,J as g,K as y}from"./jwt-decode.esm.95147216.js";import{a as l,b as i}from"./workspaceStore.ef22b01d.js";import{s as w}from"./index.82e2f482.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang.d9ce890e.js";import"./userStore.58432b7f.js";import"./url.8c481a5a.js";import"./colorHelpers.359e9af7.js";import"./PlayerConfigProvider.33ca3e11.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="1ff7c07c-c08a-4fd7-8a0a-e21fbf817b65",t._sentryDebugIdIdentifier="sentry-dbid-1ff7c07c-c08a-4fd7-8a0a-e21fbf817b65")}catch{}})();class I{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await l(),s=n(),e=r({render:()=>u(h)});o.init(),c(e,i,t),I.init(),e.use(i),e.use(s),e.use(f),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",m),a(e,b),a(e,g),a(e,y)})();
//# sourceMappingURL=player.b5604438.js.map
