import{u as r}from"./userStore.58432b7f.js";import{W as n}from"./PlayerConfigProvider.33ca3e11.js";import{u as c}from"./workspaceStore.ef22b01d.js";import{d,w as i,m as f,u as o,a as p,b as u,h as l,o as m,f as _}from"./jwt-decode.esm.95147216.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="03e39b5e-7d5b-410a-bc2e-4784bafc3dd1",t._sentryDebugIdIdentifier="sentry-dbid-03e39b5e-7d5b-410a-bc2e-4784bafc3dd1")}catch{}})();const v=d({__name:"App",setup(t){const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(b,w)=>{const s=f("RouterView");return o(e).state.workspace?(m(),p(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[_(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{v as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.d9ce890e.js.map
