import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.3cf02d12.js";import{d as l,e5 as m,eb as b,a5 as g,f as y,u as a,o as w,_ as k}from"./jwt-decode.esm.95147216.js";import{u as h}from"./workspaceStore.ef22b01d.js";import"./index.82e2f482.js";import"./CircularLoading.8337813d.js";import"./Logo.4a9353b0.js";import"./string.c6b418fe.js";import"./index.8cd0d351.js";import"./userStore.58432b7f.js";import"./url.8c481a5a.js";import"./colorHelpers.359e9af7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dd32748e-eb8b-40b1-b8c3-b1966f8f2bf9",e._sentryDebugIdIdentifier="sentry-dbid-dd32748e-eb8b-40b1-b8c3-b1966f8f2bf9")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=b(),r=h(),_=async()=>{const{redirect:s,...n}=t.query;if(s){await o.push({path:s,query:n,params:t.params});return}o.push({name:"playerHome",query:n})};return(s,n)=>{var c,d,p,u,i;return w(),g("div",v,[y(f,{"logo-url":(d=(c=a(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=a(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=a(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const U=k(I,[["__scopeId","data-v-12c690e1"]]);export{U as default};
//# sourceMappingURL=Login.cdbd06a3.js.map
