import{O as r}from"./index.82e2f482.js";import{d as l,k as u,a5 as i,f as t,b as n,u as o,o as c,g as s,A as f,da as b}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="bbe781a9-89d4-4699-8a8b-608bca2e815a",e._sentryDebugIdIdentifier="sentry-dbid-bbe781a9-89d4-4699-8a8b-608bca2e815a")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new r().logoutCallback()}),(a,d)=>(c(),i("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.e3285221.js.map
