import"./jwt-decode.esm.95147216.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="954e9984-1ba7-4b3d-b7f8-c8f7fe431d39",t._sentryDebugIdIdentifier="sentry-dbid-954e9984-1ba7-4b3d-b7f8-c8f7fe431d39")}catch{}})();const s={HOMEPAGE:{}.VITE_HOMEPAGE_URL||"https://abstra.io",DOCS:{}.VITE_DOCS_URL||"https://abstra.io/docs",CLOUD:{}.VITE_CONSOLE_URL||"https://cloud.abstra.io",GITHUB:{}.VITE_GITHUB_URL||"https://github.com/abstra-app/abstra-lib"},d=t=>{if(!t)return s.DOCS;const e=t.startsWith("/")?t.slice(1):t;return`${s.DOCS}/${e}`};export{s as A,d as b};
//# sourceMappingURL=constants.5f7db9f7.js.map
