import{A as o}from"./index.2366fc23.js";import{d as r,c as a,a5 as f,f as p,u as d,ea as c,h as l,o as i,_ as u}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="cd789f6d-1600-4011-9871-7c1ffa62eebf",e._sentryDebugIdIdentifier="sentry-dbid-cd789f6d-1600-4011-9871-7c1ffa62eebf")}catch{}})();const _=r({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=a(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,m)=>t.stepsInfo?(i(),f("nav",{key:0,class:c(["p-steps",{"full-screen":!t.isPreview}])},[p(d(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):l("",!0)}});const b=u(_,[["__scopeId","data-v-58fdd395"]]);export{b as S};
//# sourceMappingURL=Steps.b9a883e9.js.map
