import{f as d,e7 as o,eX as u}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="30c8d2f9-cb8a-4ef8-867f-197fe0ff7f3b",e._sentryDebugIdIdentifier="sentry-dbid-30c8d2f9-cb8a-4ef8-867f-197fe0ff7f3b")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(f){return Object.getOwnPropertyDescriptor(n,f).enumerable}))),r.forEach(function(f){c(e,f,n[f])})}return e}function c(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=a({},t,n.attrs);return d(o,a({},r,{icon:u}),null)};i.displayName="LoadingOutlined";i.inheritAttrs=!1;const s=i;export{s as L};
//# sourceMappingURL=LoadingOutlined.d228c4b5.js.map
