@import"https://cdn.jsdelivr.net/npm/@vue-flow/core@1.41.7/dist/style.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/core@1.41.7/dist/theme-default.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/controls@latest/dist/style.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/minimap@latest/dist/style.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/node-resizer@latest/dist/style.css";html[data-v-f0dbbd69],body[data-v-f0dbbd69],#app[data-v-f0dbbd69]{margin:0;height:100%}#app[data-v-f0dbbd69]{text-transform:uppercase;font-family:JetBrains Mono,monospace;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-align:center;color:#2c3e50}.vue-flow__minimap[data-v-f0dbbd69]{transform:scale(75%);transform-origin:bottom right}.basic-flow.dark[data-v-f0dbbd69]{background:#2d3748;color:#fffffb}.basic-flow.dark .vue-flow__node[data-v-f0dbbd69]{background:#4a5568;color:#fffffb}.basic-flow.dark .vue-flow__node.selected[data-v-f0dbbd69]{background:#333;box-shadow:0 0 0 2px #2563eb}.basic-flow .vue-flow__controls[data-v-f0dbbd69]{display:flex;flex-wrap:wrap;justify-content:center}.basic-flow.dark .vue-flow__controls[data-v-f0dbbd69]{border:1px solid #fffffb}.basic-flow .vue-flow__controls .vue-flow__controls-button[data-v-f0dbbd69]{border:none;border-right:1px solid #eee}.basic-flow .vue-flow__controls .vue-flow__controls-button svg[data-v-f0dbbd69]{height:100%;width:100%}.basic-flow.dark .vue-flow__controls .vue-flow__controls-button[data-v-f0dbbd69]{background:#333;fill:#fffffb;border:none}.basic-flow.dark .vue-flow__controls .vue-flow__controls-button[data-v-f0dbbd69]:hover{background:#4d4d4d}.basic-flow.dark .vue-flow__edge-textbg[data-v-f0dbbd69]{fill:#292524}.basic-flow.dark .vue-flow__edge-text[data-v-f0dbbd69]{fill:#fffffb}.vue-flow__handle[data-v-f0dbbd69]{opacity:0}
