import{N as d,c as l}from"./jwt-decode.esm.95147216.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="717cb6b6-5987-4707-a800-129e246715c0",r._sentryDebugIdIdentifier="sentry-dbid-717cb6b6-5987-4707-a800-129e246715c0")}catch{}})();const f=r=>{const e=d({loading:!0,result:null,error:null}),n=t=>(e.value={loading:!1,result:t,error:null},t),s=t=>{e.value={loading:!1,result:null,error:t}},o=async()=>(e.value={loading:!0,result:e.value.result,error:null},r().then(n).catch(s));o();const u=l(()=>e.value.loading),a=l(()=>e.value.result),c=l(()=>e.value.error);return{loading:u,result:a,error:c,refetch:o}};export{f as a};
//# sourceMappingURL=asyncComputed.15a1493f.js.map
