import{_ as c,o,a5 as n,a7 as s,e as d,h as a}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="83a4d989-3c59-4fe8-9ef2-5f2a19f61536",e._sentryDebugIdIdentifier="sentry-dbid-83a4d989-3c59-4fe8-9ef2-5f2a19f61536")}catch{}})();const r={},f={class:"base-layout"},i={class:"base-middle"},_={class:"content"},l={class:"left"},u={key:0,class:"base-footer"},y={key:0};function b(e,t){return o(),n("div",f,[s(e.$slots,"sidebar",{},void 0,!0),d("section",i,[s(e.$slots,"navbar",{},void 0,!0),d("section",_,[d("section",l,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):a("",!0)]),e.$slots.chat?(o(),n("section",y,[s(e.$slots,"chat",{},void 0,!0)])):a("",!0)])])])}const g=c(r,[["render",b],["__scopeId","data-v-da85ecdc"]]);export{g as B};
//# sourceMappingURL=BaseLayout.0056f742.js.map
