import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.dffc3ca0.js";import{B as m}from"./BaseLayout.0056f742.js";import{d as l,ae as y,c1 as v,_ as u,aZ as g,a_ as b,o as _,a5 as h,e as r,a6 as n,eb as w,e5 as S,k,a as L,b as s,f as i,u as x}from"./jwt-decode.esm.95147216.js";import{u as B}from"./editor.68f739b4.js";import{A as I}from"./index.ca714ac8.js";import"./Logo.4a9353b0.js";import"./workspaceStore.ef22b01d.js";import"./userStore.58432b7f.js";import"./url.8c481a5a.js";import"./colorHelpers.359e9af7.js";import"./index.82e2f482.js";import"./linters.84e3ac47.js";import"./asyncComputed.15a1493f.js";import"./constants.5f7db9f7.js";import"./index.574c12ce.js";import"./Breadcrumb.fba01eee.js";import"./index.c7a02ea6.js";import"./index.b1615145.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="86251b2a-f601-4d5e-8138-9f3aab6d6fd3",e._sentryDebugIdIdentifier="sentry-dbid-86251b2a-f601-4d5e-8138-9f3aab6d6fd3")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(o)}}});const P={class:"v-spinner"};function D(e,o,a,d,c,p){return g((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const R=u($,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const o=w(),a=S(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=p();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"editor"})}),(t,A)=>(_(),L(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[r("div",j,[i(R)])]),_:1}))}});const Y=u(z,[["__scopeId","data-v-d2a19803"]]);export{Y as default};
//# sourceMappingURL=ProjectLogin.ab14d657.js.map
