import{L as a}from"./Logo.4a9353b0.js";import{d,o as n,a as r,u as i}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="d2e3e898-0fe7-47b4-adbd-552de2737412",e._sentryDebugIdIdentifier="sentry-dbid-d2e3e898-0fe7-47b4-adbd-552de2737412")}catch{}})();const f="/assets/logo.0faadfa2.svg",b=d({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return n(),r(a,{"image-url":i(f),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{b as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.dffc3ca0.js.map
