.upper[data-v-eb7f2204]{width:100%;padding:4px 12px}.upper .recent-container[data-v-eb7f2204]{overflow:scroll}.upper .recent-container[data-v-eb7f2204]::-webkit-scrollbar{display:none}.upper .recent-container .recent-thread[data-v-eb7f2204]{cursor:pointer}.upper .recent-container .current-thread[data-v-eb7f2204]{border-color:#d1405675}.upper[data-v-eb7f2204] .ant-btn{height:fit-content}.upper[data-v-eb7f2204] .ant-btn-icon-only{display:flex;justify-content:center;align-items:center;width:22px}.lower[data-v-66b0a5f4]{border:1px solid #f0f0f0;border-radius:10px;width:calc(100% - 20px);margin:10px 0}.lower .bottom-lower[data-v-66b0a5f4]{padding:6px}.lower .bottom-lower .info[data-v-66b0a5f4]{display:flex;gap:8px;padding-left:4px}[data-v-08b28b34]:root{--main-font-family: DM Sans, sans-serif}[data-v-08b28b34]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-08b28b34]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-08b28b34]{background-color:#fff;padding:10px}.suggestions-container[data-v-08b28b34]{width:calc(100% - 40px);height:100%;padding:8px}.suggestions-container .suggestion[data-v-08b28b34]{display:flex;align-items:center;gap:10px;border-radius:8px;background-color:#f9fafb;padding:16px;cursor:pointer;transition:all .2s}.suggestions-container .suggestion[data-v-08b28b34]:hover{background-color:#f3f3f3}.suggestions-container .suggestion .icon[data-v-08b28b34]{height:24px;width:24px;color:#d14056}.suggestions-container .suggestion .title[data-v-08b28b34]{font-size:15px;color:#000}.container[data-v-952e7741]{display:flex;flex-direction:column;justify-content:space-between;align-items:center;height:100%;width:0;transition:width .3s ease;overflow:hidden;background-color:#fff}.container.visible[data-v-952e7741]{width:100%;overflow:visible}.container.visible.console[data-v-952e7741]{width:25vw}.container .content[data-v-952e7741]{flex:1;flex-direction:column;overflow-y:hidden;padding:0 14px;text-align:left;width:100%}.container .content.console[data-v-952e7741]{width:25vw}.container .content .scroll[data-v-952e7741]{overflow-y:auto}.container .content .scroll[data-v-952e7741]::-webkit-scrollbar{display:none}.container .content .empty-container[data-v-952e7741]{height:100%}.container .content .entry[data-v-952e7741]{padding-top:4px;padding-bottom:12px}.container .content .entry .entry-owner[data-v-952e7741]{display:flex;gap:4px;align-items:center;margin-bottom:4px}.container .content .entry .entry-owner .avatar[data-v-952e7741]{display:flex;justify-content:center;align-items:center;margin-right:2px;font-size:12px!important}.container .content .entry.tool-response[data-v-952e7741]{margin-top:-8px}.container .content[data-v-952e7741] .ant-collapse-header{padding:0;color:#000}.container .content[data-v-952e7741] .ant-collapse-header .ant-collapse-expand-icon{height:6px}.container .content[data-v-952e7741] .ant-collapse-header .ant-collapse-arrow{font-size:8px}.container .content[data-v-952e7741] .ant-collapse-borderless{background-color:#fff}.container .content[data-v-952e7741] .ant-collapse-content-box{padding-bottom:2px}.container .content .timeline-item[data-v-952e7741]{padding-right:20px}.container .content .timeline-item .remove-action[data-v-952e7741]{display:none}.container .content .timeline-item[data-v-952e7741]:hover{padding-right:0}.container .content .timeline-item:hover .remove-action[data-v-952e7741]{display:block;cursor:pointer;color:#505050}.container .content .timeline-item:hover .remove-action[data-v-952e7741]:hover{color:#101010}.container .scroll-to-bottom[data-v-952e7741]{display:flex;align-items:center;justify-content:center;position:absolute;right:8px;bottom:175px;width:32px;height:32px;background:white;border-radius:50%;padding:4px;box-shadow:#0003 0 0 4px}.v-enter-from[data-v-952e7741]{transform:translateY(20px);opacity:0}.v-enter-to[data-v-952e7741]{transform:translate(0);opacity:1}.v-enter-active[data-v-952e7741],.v-leave-active[data-v-952e7741]{transition:all .3s ease}.v-leave-to[data-v-952e7741]{transform:translateY(-20px);opacity:0}
