import{d as f,c as b,o as d,a as r,b as a,f as l,u as n,de as i,a7 as p,h as u,ez as y,eA as g,bR as c,aV as m,e6 as _}from"./jwt-decode.esm.95147216.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="271d5dde-b63e-4c88-b768-6664b185651c",t._sentryDebugIdIdentifier="sentry-dbid-271d5dde-b63e-4c88-b768-6664b185651c")}catch{}})();const h=f({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,s=b(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip);return(o,k)=>s.value?(d(),r(n(m),{key:0,title:s.value},{default:a(()=>[l(n(c),y(g(o.$props)),{default:a(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?u("",!0):p(o.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(d(),r(n(c),y(_({key:1},o.$props)),{default:a(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?u("",!0):p(o.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{h as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.ce90d792.js.map
