import{d as k,r as B,k as I,o as n,a as u,b as f,f as A,g as P,ed as S,ea as C,eF as D,u as y,bR as N,eW as V,_ as W,eb as q,h as g,e as b,a5 as c,ec as v,ef as x,aR as w,I as E,J as F}from"./jwt-decode.esm.95147216.js";import{S as L}from"./Steps.b9a883e9.js";import{W as $}from"./PlayerConfigProvider.33ca3e11.js";import"./index.2366fc23.js";import"./colorHelpers.359e9af7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="79fa233b-61bb-4798-8958-44596c5d03f9",o._sentryDebugIdIdentifier="sentry-dbid-79fa233b-61bb-4798-8958-44596c5d03f9")}catch{}})();const K=k({__name:"ActionButton",props:{action:{},displayName:{},disabled:{type:Boolean},loading:{type:Boolean}},emits:["click"],setup(o,{emit:t}){const d=o,l=B(null);return I(()=>{l.value&&d.action.setElement(l.value)}),(r,i)=>(n(),u(y(V),null,{default:f(()=>[A(y(N),{ref_key:"element",ref:l,class:C(["next-button",r.disabled?"disabled":""]),loading:r.loading,disabled:r.disabled,onClick:i[0]||(i[0]=p=>t("click")),onKeydown:i[1]||(i[1]=D(p=>t("click"),["enter"]))},{default:f(()=>[P(S(r.displayName),1)]),_:1},8,["loading","disabled","class"])]),_:1}))}});const R=W(K,[["__scopeId","data-v-aea27bb7"]]),J={class:"form"},M={class:"form-wrapper"},O={key:0,class:"buttons"},z=k({__name:"WidgetPreview",setup(o){const t=q(),d=B([]);function l(e){return E[e]||F[e]||null}function r(e){try{const s=JSON.parse(e);if(s.component=l(s.type),!s.component)throw new Error(`Widget ${s.type} not found`);return s.component?s:null}catch{return null}}function i(){const e=t.query.widget;return Array.isArray(e)?e.map(r).filter(Boolean):[r(e)]}function p(){return t.query.steps==="true"}function _(){const e=t.query.button;return e?Array.isArray(e)?e:[e]:[]}const m=e=>({name:e,isDefault:!1,isFocused:!1,focusOnButton:()=>{},addKeydownListener:()=>{},setElement:()=>{}});return(e,s)=>(n(),u($,{"main-color":"#d14056",class:"preview",background:"#fbfbfb","font-family":"Inter",locale:"en"},{default:f(()=>[p()?(n(),u(L,{key:0,class:"steps","steps-info":{current:1,total:3},"is-preview":""})):g("",!0),b("div",J,[b("div",M,[(n(!0),c(w,null,v(i(),(a,h)=>(n(),c("div",{key:h,class:"widget"},[(n(),u(x(a.component),{"user-props":a.userProps,value:a.userProps.value,errors:d.value},null,8,["user-props","value","errors"]))]))),128))]),_().length?(n(),c("div",O,[(n(!0),c(w,null,v(_(),a=>(n(),u(R,{key:a,"display-name":m(a).name,action:m(a)},null,8,["display-name","action"]))),128))])):g("",!0)])]),_:1}))}});const U=W(z,[["__scopeId","data-v-d3d01da6"]]);export{U as default};
//# sourceMappingURL=WidgetPreview.99c7b8fc.js.map
