import{C as r,E as t,K as i,a as f,M as c,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.a1733007.js";import"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6094adfc-d667-4dd9-a66d-044b7870a515",e._sentryDebugIdIdentifier="sentry-dbid-6094adfc-d667-4dd9-a66d-044b7870a515")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,f as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.65ae0d14.js.map
