import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.2141901f.js";import{d as i,eb as s,a,u as m,o as d}from"./jwt-decode.esm.95147216.js";import"./router.09c25b35.js";import"./index.574c12ce.js";import"./fetch.a9ee3277.js";import"./record.44df96f2.js";import"./SaveButton.e698094d.js";import"./ExclamationCircleOutlined.bfcd4f7f.js";import"./CrudView.178ed8b6.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bfb97102.js";import"./constants.5f7db9f7.js";import"./url.8c481a5a.js";import"./PhDotsThreeVertical.vue.3f13d85f.js";import"./index.b1615145.js";import"./asyncComputed.15a1493f.js";import"./polling.e0761cfe.js";import"./omniChatStore.5c421f6e.js";import"./uuid.36c0f5f6.js";import"./PhCopySimple.vue.0dac09a8.js";import"./PhPencil.vue.8eeff64f.js";import"./index.8cd0d351.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="8bd61f95-3cf4-418f-9eba-03ed332a6547",o._sentryDebugIdIdentifier="sentry-dbid-8bd61f95-3cf4-418f-9eba-03ed332a6547")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(f,c)=>(d(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.6a4402df.js.map
