import{d as b,e5 as f,eb as m,o as l,a as p,b as u,a5 as _,ec as g,f as y,e as v,ed as k,u as n,aR as w}from"./jwt-decode.esm.95147216.js";import{A as I,T}from"./Card.6c9b2903.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="966a996a-de0f-4944-a2ca-4828e75816bb",e._sentryDebugIdIdentifier="sentry-dbid-966a996a-de0f-4944-a2ca-4828e75816bb")}catch{}})();const R=b({__name:"TablesTabs",setup(e){const a=f(),t=m(),c=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(l(),p(n(T),{"active-key":n(c),options:r,"onUpdate:activeKey":i},{default:u(()=>[(l(),_(w,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:u(()=>[v("span",null,k(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{R as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.43b35389.js.map
