import{f as l,e7 as o,eZ as u}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8448c772-118a-4d3b-b7a7-a16cfd808110",e._sentryDebugIdIdentifier="sentry-dbid-8448c772-118a-4d3b-b7a7-a16cfd808110")}catch{}})();function c(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){d(e,a,n[a])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=c({},t,n.attrs);return l(o,c({},r,{icon:u}),null)};i.displayName="ExclamationCircleOutlined";i.inheritAttrs=!1;const s=i;export{s as E};
//# sourceMappingURL=ExclamationCircleOutlined.bfcd4f7f.js.map
