import"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="999a6362-3a89-47da-95b2-e3ca9a303ea3",e._sentryDebugIdIdentifier="sentry-dbid-999a6362-3a89-47da-95b2-e3ca9a303ea3")}catch{}})();const t=(...e)=>window.fetch(...e);export{t as l};
//# sourceMappingURL=fetch.a9ee3277.js.map
