import{i as b}from"./metadata.b063d26f.js";import{W as h}from"./Watermark.e2acb72e.js";import{F as k}from"./PhArrowSquareOut.vue.dcd6453d.js";import{d as v,e5 as w,c as x,r as C,u as e,a5 as m,f as d,b as r,h as D,o as a,a as n,g as f,T as y,aR as I,ec as z,de as _,ef as T,ed as F,ea as B,_ as H}from"./jwt-decode.esm.95147216.js";import{u as L}from"./workspaceStore.ef22b01d.js";import"./index.2a2a2f4c.js";import{L as N}from"./LoadingOutlined.d228c4b5.js";import{C as S}from"./Card.6c9b2903.js";import"./PhUserList.vue.8ad60021.js";import"./PhWebhooksLogo.vue.c419935e.js";import"./index.82e2f482.js";import"./constants.5f7db9f7.js";import"./userStore.58432b7f.js";import"./url.8c481a5a.js";import"./colorHelpers.359e9af7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="a721dbec-86e2-49bc-95b2-6aa793366b75",o._sentryDebugIdIdentifier="sentry-dbid-a721dbec-86e2-49bc-95b2-6aa793366b75")}catch{}})();const V={key:0,class:"home-container"},W=v({__name:"Home",setup(o){const i=w(),l=L(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(p=>p.id!=="home"))||[]}),c=C(null),g=async(s,p)=>{c.value=p,await i.push({path:`/${s}`}),c.value=null};return(s,p)=>e(l).state.workspace?(a(),m("div",V,[d(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(a(!0),m(I,{key:1},z(u.value,t=>(a(),n(e(S),{key:t.id,class:B(["form-card",{loading:c.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(t.path,t.id)},{default:r(()=>[d(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(T(e(b)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),d(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(F(t.name),1)]),_:2},1024),c.value!==t.id?(a(),n(e(k),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),d(h,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Z=H(W,[["__scopeId","data-v-060376d1"]]);export{Z as default};
//# sourceMappingURL=Home.d950cbee.js.map
