[data-v-58fdd395]:root{--main-font-family: DM Sans, sans-serif}[data-v-58fdd395]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-58fdd395]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-58fdd395]{background-color:#fff;padding:10px}.p-steps[data-v-58fdd395]{margin:20px auto;position:relative;padding:0;list-style-type:none;display:flex;width:calc(100% - 40px)}.p-steps.full-screen[data-v-58fdd395]{width:600px}
