import{d as a,o as d,a5 as s,e as l,a7 as r,ea as n,_ as f}from"./jwt-decode.esm.95147216.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="16738056-b763-4b7c-83c5-8951df93f56a",t._sentryDebugIdIdentifier="sentry-dbid-16738056-b763-4b7c-83c5-8951df93f56a")}catch{}})();const c=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,o)=>(d(),s("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[l("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[r(e.$slots,"default",{},void 0,!0)],2)],2))}});const u=f(c,[["__scopeId","data-v-fb4d67f9"]]);export{u as C};
//# sourceMappingURL=ContentLayout.231b4f8d.js.map
