import{h as t}from"./router.09c25b35.js";import"./jwt-decode.esm.95147216.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="900abe9a-15e7-4a46-a321-ac71b27a698a",a._sentryDebugIdIdentifier="sentry-dbid-900abe9a-15e7-4a46-a321-ac71b27a698a")}catch{}})();class i{async create(e){return t.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return t.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return t.get(`organizations/${e}/members`)}async get(e,n){return t.get(`organizations/${e}/members/${n}`)}async update(e,n,r){return t.patch(`organizations/${e}/members/${n}`,r)}}export{i as M};
//# sourceMappingURL=member.43ebbec6.js.map
