import{O as s}from"./OmniChat.069fde80.js";import{u as a}from"./omniChatStore.5c421f6e.js";import{d as i,eb as d,u as t,o as c,a as l,h as u}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="ea095466-e794-440a-b284-d28d98d73d32",e._sentryDebugIdIdentifier="sentry-dbid-ea095466-e794-440a-b284-d28d98d73d32")}catch{}})();const b=i({__name:"ConsoleOmniChat",setup(e){const n=d().params.projectId,o=a();return o.init("console",n),(p,m)=>t(o).controller&&t(o).repository?(c(),l(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)}},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{b as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.85b6c77f.js.map
