import{X as s,dJ as i,dK as d}from"./jwt-decode.esm.95147216.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8b04af8c-228b-4c27-be23-a81b0d9c0972",e._sentryDebugIdIdentifier="sentry-dbid-8b04af8c-228b-4c27-be23-a81b0d9c0972")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:b,TimePicker:f,QuarterPicker:a,RangePicker:c}=i(d),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:b,RangePicker:c,TimePicker:f,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,c as R,t as W};
//# sourceMappingURL=dayjs.be90c3c1.js.map
