.oidc-container[data-v-3f7d7e6f]{display:flex;justify-content:center;flex-direction:column;align-items:center;width:100%;height:100%;padding:50px;box-sizing:border-box}.oidc-container a[data-v-3f7d7e6f]{text-decoration:underline}.centered[data-v-3f7d7e6f]{text-align:center;margin:0}[data-v-a1043ff4]:root{--main-font-family: DM Sans, sans-serif}[data-v-a1043ff4]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-a1043ff4]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-a1043ff4]{background-color:#fff;padding:10px}.passwordless[data-v-a1043ff4]{width:100%;max-width:500px;box-shadow:0 4px 8px #0000001a;padding:24px;border-radius:8px;margin:auto;font-family:DM Sans,sans-serif;background-color:#fff;color:#000}.passwordless[data-v-a1043ff4] .ant-form{color:#000000d9}.passwordless[data-v-a1043ff4] .ant-btn-default:disabled{color:#00000040;border-color:#00000040}.passwordless .header[data-v-a1043ff4]{margin:25px auto}.passwordless .header h2[data-v-a1043ff4]{font-size:24px;font-weight:500;padding:0;margin:0;font-family:DM Sans,sans-serif}.passwordless .section[data-v-a1043ff4]{display:flex;flex-direction:column;gap:20px}.passwordless .section .description[data-v-a1043ff4]{font-size:16px;font-weight:400;text-align:center}.passwordless .section .footer[data-v-a1043ff4]{font-size:14px;font-weight:400;text-align:center}.loading[data-v-a1043ff4]{margin:20px 0}
